<?php

namespace App\Controller\Catalog;

use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\Session\Session;
use App\Entity\Canton;
use App\Entity\Provincia;

class CatalogosCantonesController extends AbstractController
{
  private $rolAccess = 50;
    /**
     * @Route("Catalogos/Cantones", name="catalogo_canton_index")
     */
    public function catalogo__canton_index()
    {
     if ( $this->access() ){
       $select['provincia']    =   $this->getDoctrine()->getRepository(Provincia::class)->findBy(array(), array('provinciadescripcion' => 'ASC'));
       return $this->render('ccp/catalog/canton.html.twig', array( 'select' => $select ) );
     }
     else
       return $this->redirectToRoute('ccp_app_index', ['e'   => ""] );
    }

     /**
       * @Route("Catalogos/getAllCantones/json", name="get_all_Cantones_json")
       */
     public function get_all_Cantones_json(Request $request) {
      if($request->isXmlHttpRequest() AND  $this->access() ) {
     	  $em  = $this->getDoctrine()->getManager();
        $sql = "SELECT c.CantonID, c.CantonDescripcion, p.ProvinciaDescripcion, p.ProvinciaID FROM Canton c INNER JOIN Provincia p ON p.ProvinciaID = c.ProvinciaID";
        $stm = $em->getConnection()->prepare( $sql );
        $stm->execute();
        return new JsonResponse([ 'data' => $stm->fetchAll() ], Response::HTTP_OK, ['content-type'=>'application/json']);
      } else {
        return new JsonResponse([ 'data' => array('' => '' ) ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
      }
     }

  /**
  * @Route("Catalogos/CantonAdd", name="catalogo_canton_add", methods={"POST"})
  */
   public function catalogo_canton_add(Request $request) {
    if(!$request->isXmlHttpRequest() AND  !$this->access() ) {
      return new JsonResponse([ 'data' => array('' => '' ) ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
    }
    try {
      $nombre = $request->get('nombre');
      $provincia = $request->get('provincia');
      $xid = $request->get('xid');
      $em = $this->getDoctrine()->getManager();
      if($xid == ""){
         $var = new Canton();
      }else{
         $var = $em->getRepository(Canton::class)->find($xid);
      }
      $var->setCantondescripcion($nombre);
      $var->setProvinciaid($em->getReference('App\Entity\Provincia', $provincia));
      $em->persist($var);
      $em->flush();
      $message = ($xid === null) ? "Registro Guardado Exitosamente" : "Registro Actualizado Exitosamente";
      return new JsonResponse([ 'message' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
    } catch (Exception $e) {
    	 $message = "Ha ocurrido un error";
      return new JsonResponse([ 'data' => $message ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
    }
  }

  /**
    * @Route("Catalogos/CantonDelete", name="catalogo_canton_delete", methods={"POST"})
    */
  public function catalogo_canton_delete(Request $request){
   if(!$request->isXmlHttpRequest() AND  !$this->access() ) {
    return new JsonResponse([ 'data' => array('' => '' ) ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
   }
   try {
       $ids = $request->get('ids');
       $em = $this->getDoctrine()->getManager();
       foreach ($ids as $id) {
           $rol = $this->getDoctrine()->getRepository(Canton::class)->find($id['id']);
           $em->remove($rol);
           $em->flush();
    }
      $message = "Registros eliminados exitosamente";
      return new JsonResponse([ 'message' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
    } catch (Exception $e) {
       $message = "Ha ocurrido un error";
       return new JsonResponse([ 'data' => $message ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
    }
  }
  private function access(){
   $session = new Session();
   if ( $session->get('useridrol') >= $this->rolAccess )
     return TRUE;
   else
     return FALSE;
  }
}
