<?php

namespace App\Controller\Catalog;

use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use App\Entity\Curso;
use App\Entity\Tipoproceso;
use App\Entity\Institucion;
use App\Entity\Centrocivico;
use Symfony\Component\HttpFoundation\Session\Session;
use DateTime;

class CatalogosCursosController extends AbstractController{
  private $rolAccess = 50;
  /**
   * @Route("Catalogos/Cursos", name="catalogo_cursos_index")
   */
  public function catalogo_cursos_index(){
   if ( $this->access() ){
    $select['centro'] = $this->getDoctrine()->getRepository(Centrocivico::class)->findBy(array(), array('centrocivicodescripcion' => 'ASC'));
    $select['institucion'] = $this->getDoctrine()->getRepository(Institucion::class)->findBy(array(), array('instituciondescrip' => 'ASC'));
    $select['tipo'] = $this->getDoctrine()->getRepository(Tipoproceso::class)->findBy(array(), array('tipoprocesonombre' => 'ASC'));
    return $this->render('ccp/catalog/cursos.html.twig', array( 'select' => $select ) );
   }
   else
     return $this->redirectToRoute('ccp_app_index', ['e'   => ""] );
  }

  /**
    * @Route("Catalogos/getAllCursos/json", name="get_all_cursos_json")
    */
  public function get_all_cursos_json(Request $request) {
   if($request->isXmlHttpRequest() AND  $this->access() ) {
     $em  = $this->getDoctrine()->getManager();
     $sql = "SELECT i.InstitucionID, t.TipoProcesoID, t.TipoProcesoNombre, c.CursoNombre, c.CursoID, cc.CentroCivicoID, cc.CentroCivicoDescripcion, c.CursoEstado, c.CursoCodigo,
CONCAT ( i.InstitucionSiglas, ', ', STRING_AGG(CONVERT(NVARCHAR(max), ISNULL(n.InstitucionSiglas ,'')), ', ') ) InstitucionDescrip
FROM Curso c INNER JOIN Institucion i ON i.InstitucionID = c.InstitucionID INNER JOIN TipoProceso t ON t.TipoProcesoID = c.TipoProcesoID INNER JOIN CentroCivico cc ON cc.CentroCivicoID = c.CentroCivicoID
	LEFT JOIN CursoInstitucion q ON q.CursoID = c.CursoID LEFT JOIN Institucion n ON n.InstitucionID = q.InstitucionID
GROUP BY c.CursoID, i.InstitucionID, t.TipoProcesoID, t.TipoProcesoNombre, c.CursoNombre, cc.CentroCivicoID, cc.CentroCivicoDescripcion, c.CursoEstado, c.CursoCodigo, i.InstitucionSiglas";
     $stm = $em->getConnection()->prepare( $sql );
     $stm->execute();
     return new JsonResponse([ 'data' => $stm->fetchAll() ], Response::HTTP_OK, ['content-type'=>'application/json']);
   } else {
     return new JsonResponse([ 'data' => array('' => '' ) ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
   }
  }

  /**
  * @Route("Catalogos/CursoAdd", name="catalogo_cursos_add", methods={"POST"})
  */
   public function catalogo_cursos_add(Request $request) {
    if(!$request->isXmlHttpRequest() AND  !$this->access() ) {
      return new JsonResponse([ 'data' => array('' => '' ) ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
    }
    try {
      $session = new Session();
      $nombre = $request->get('nombre');
      $centro = $request->get('centro');
      $tipo = $request->get('tipo');
      $cursocodigo = $request->get('codigo');
      $institucion = $request->get('institucion');
      //$estado = $request->get('estado');
      $xid = $request->get('xid');
      $em = $this->getDoctrine()->getManager();
      $codCurso = "";
      if($xid == ""){
         $var = new Curso();
         $var->setCursousrcrea( $session->get('username') );
         $var->setCursofeccrea( date("Y-m-d H:i:s") );
         $codCurso = $this->setCodigoProceso( $centro );
         $var->setCursocodigo( $codCurso );
      }else{
         $var = $em->getRepository(Curso::class)->find($xid);
         $codCurso = $var->getCursocodigo( );
      }
      $var->setCursonombre($nombre);
      $var->setCentrocivicoid($em->getReference('App\Entity\Centrocivico', $centro));
      $var->setInstitucionid($em->getReference('App\Entity\Institucion', $institucion));
      $var->setTipoprocesoid($em->getReference('App\Entity\Tipoproceso', $tipo));
      $var->setCursousrmod( $session->get('username') );
      $var->setCursofecmod( date("Y-m-d H:i:s") );
      $var->setCursoestado('SI');
      $em->persist($var);
      $em->flush();
      $this->updateIntituciones( $codCurso, $request->get('institucion2') );
      $message = ($xid === null) ? "Registro Guardado Exitosamente" : "Registro Actualizado Exitosamente";
      return new JsonResponse([ 'message' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
    } catch (Exception $e) {
    	$message = "Ha ocurrido un error";
      return new JsonResponse([ 'data' => $message ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
    }
  }

  /**
    * @Route("Catalogos/CursoDelete", name="catalogo_cursos_delete", methods={"POST"})
    */
  public function catalogo_cursos_delete(Request $request){
   if(!$request->isXmlHttpRequest() AND  !$this->access() ) {
    return new JsonResponse([ 'data' => array('' => '' ) ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
   }
   try {
       $ids = $request->get('ids');
       $em = $this->getDoctrine()->getManager();
       foreach ($ids as $id) {
           $rol = $this->getDoctrine()->getRepository(Curso::class)->find($id['id']);
           $em->remove($rol);
           $em->flush();
      }
      $message = "Registros eliminados exitosamente";
      return new JsonResponse([ 'message' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
    } catch (Exception $e) {
       $message = "Ha ocurrido un error";
       return new JsonResponse([ 'data' => $message ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
    }
  }

  private function setCodigoProceso($centro){
    $em  = $this->getDoctrine()->getManager();
    $sql = "SELECT CentroCivicoSiglas, CentroCivicoConsecCurso FROM CentroCivico WHERE CentroCivicoID = $centro";
    $statement = $em->getConnection()->prepare( $sql );
	  $statement->execute();
	  $result = $statement->fetchAll();
    $codCentro = "ND";
    $numCursos = 0;
    foreach ($result as $key => $data) {
     $codCentro = $data["CentroCivicoSiglas"];
     $numCursos = $data["CentroCivicoConsecCurso"]+1;
     $sql = "UPDATE CentroCivico	SET CentroCivicoConsecCurso=$numCursos WHERE CentroCivicoID = $centro";
     $statement = $em->getConnection()->prepare( $sql );
     $statement->execute();
    }
    return "PF-$codCentro-$numCursos";
  }

  private function updateIntituciones( $code, $institucion ){
    $em = $this->getDoctrine()->getManager();
    $sql = "SELECT CursoID FROM Curso WHERE CursoCodigo = '$code'";
    $statement = $em->getConnection()->prepare( $sql );
	  $statement->execute();
	  $result = $statement->fetchAll();
    $curso = 0;
    foreach ($result as $key => $data) {
     $curso = $data["CursoID"];
     //---------------
     $sql = "DELETE FROM CursoInstitucion WHERE CursoID = $curso";
     $statement = $em->getConnection()->prepare( $sql );
     $statement->execute();
     foreach ($institucion as $selectedOption){
       $sql = " INSERT INTO CursoInstitucion (CursoID,InstitucionID) VALUES ($curso, $selectedOption);";
       $statement = $em->getConnection()->prepare( $sql );
       $statement->execute();
     }
    }
  }

  private function access(){
   $session = new Session();
   if ( $session->get('useridrol') >= $this->rolAccess )
     return TRUE;
   else
     return FALSE;
  }
}
