<?php

namespace App\Controller\Catalog;

use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use App\Entity\Discapacidad;
use Symfony\Component\HttpFoundation\Session\Session;

class CatalogosDiscapacidadesController extends AbstractController
{
  private $rolAccess = 50;
  /**
   * @Route("Catalogos/Discapacidades", name="catalogo_discapacidades_index")
   */
  public function catalogo_discapacidades_index(){
   if ( $this->access() ){
    $select['discapacidad'] = $this->getDoctrine()->getRepository(Discapacidad::class)->findBy(['discapacidad' => NULL], array('discapacidaddescripcion' => 'ASC'));
   	return $this->render('ccp/catalog/discapacidad.html.twig', array( 'select' => $select ) );
   }
   else
     return $this->redirectToRoute('ccp_app_index', ['e'   => ""] );
  }

  /**
    * @Route("Catalogos/getAllDiscapacidad/json", name="get_all_discapacidades_json")
    */
  public function get_all_discapacidades_json(Request $request) {
   if($request->isXmlHttpRequest() AND  $this->access() ) {
     $em  = $this->getDoctrine()->getManager();
     $sql = "SELECT dc.DiscapacidadDescripcion cat, '' item, dc.DiscapacidadID val, -1 idcat FROM Discapacidad dc WHERE dc.Discapacidad_ID IS NULL
              UNION
             SELECT d.DiscapacidadDescripcion cat,ds.DiscapacidadDescripcion item, ds.DiscapacidadID val, ds.Discapacidad_ID idcat FROM Discapacidad d JOIN Discapacidad ds ON ds.Discapacidad_ID = d.DiscapacidadID";
     $stm = $em->getConnection()->prepare( $sql );
     $stm->execute();
     return new JsonResponse([ 'data' => $stm->fetchAll() ], Response::HTTP_OK, ['content-type'=>'application/json']);
   } else {
     return new JsonResponse([ 'data' => array('' => '' ) ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
   }
  }

  /**
  * @Route("Catalogos/DiscapacidadAdd", name="catalogo_discapacidades_add", methods={"POST"})
  */
   public function catalogo_discapacidades_add(Request $request) {
    if(!$request->isXmlHttpRequest() AND  !$this->access() ) {
      return new JsonResponse([ 'data' => array('' => '' ) ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
    }
    try {
      $nombre = $request->get('nombre');
      $cat = $request->get('cat');
      $xid = $request->get('xid');
      $em = $this->getDoctrine()->getManager();
      if($xid == ""){
         $var = new Discapacidad();
      }else{
         $var = $em->getRepository(Discapacidad::class)->find($xid);
      }
      $var->setDiscapacidaddescripcion($nombre);
      if ( $cat > 0) {
        $var->setDiscapacidad($em->getReference('App\Entity\Discapacidad', $cat));
      }
      $em->persist($var);
      $em->flush();
      $message = ($xid === null) ? "Registro Guardado Exitosamente" : "Registro Actualizado Exitosamente";
      return new JsonResponse([ 'message' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
    } catch (Exception $e) {
    	 $message = "Ha ocurrido un error";
      return new JsonResponse([ 'data' => $message ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
    }
  }

  /**
    * @Route("Catalogos/DiscapacidadDelete", name="catalogo_discapacidades_delete", methods={"POST"})
    */
  public function catalogo_discapacidades_delete(Request $request){
   if(!$request->isXmlHttpRequest() AND  !$this->access() ) {
    return new JsonResponse([ 'data' => array('' => '' ) ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
   }
   try {
       $ids = $request->get('ids');
       $em = $this->getDoctrine()->getManager();
       foreach ($ids as $id) {
           $rol = $this->getDoctrine()->getRepository(Discapacidad::class)->find($id['id']);
           $em->remove($rol);
           $em->flush();
      }
      $message = "Registros eliminados exitosamente";
      return new JsonResponse([ 'message' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
    } catch (Exception $e) {
       $message = "Ha ocurrido un error";
       return new JsonResponse([ 'data' => $message ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
    }
  }

  private function access(){
   $session = new Session();
   if ( $session->get('useridrol') >= $this->rolAccess )
     return TRUE;
   else
     return FALSE;
  }
}
