<?php

namespace App\Controller\Catalog;

use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\Session\Session;
use App\Entity\Canton;
use App\Entity\Distrito;

class CatalogosDistritosController extends AbstractController
{
  private $rolAccess = 50;
    /**
     * @Route("Catalogos/Distritos", name="catalogo_distrito_index")
     */
    public function catalogo_distrito_index()
    {
     if ( $this->access() ){
       $select['canton']    =   $this->getDoctrine()->getRepository(Canton::class)->findBy(array(), array('cantondescripcion' => 'ASC'));
           return $this->render('ccp/catalog/distritos.html.twig', array( 'select' => $select ) );
     }
     else
       return $this->redirectToRoute('ccp_app_index', ['e'   => ""] );
    }

     /**
       * @Route("Catalogos/getAllDistritos/json", name="get_all_distritos_json")
       */
     public function get_all_distritos_json(Request $request) {
      if($request->isXmlHttpRequest() AND  $this->access() ) {
     	  $em  = $this->getDoctrine()->getManager();
        $sql = "SELECT c.CantonID, c.CantonDescripcion, d.DistritoID, d.DistritoDescripcion FROM Canton c INNER JOIN Distrito d ON d.CantonID = c.CantonID";
        $stm = $em->getConnection()->prepare( $sql );
        $stm->execute();
        return new JsonResponse([ 'data' => $stm->fetchAll() ], Response::HTTP_OK, ['content-type'=>'application/json']);
      } else {
        return new JsonResponse([ 'data' => array('' => '' ) ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
      }
     }

  /**
  * @Route("Catalogos/DistritoAdd", name="catalogo_distrito_add", methods={"POST"})
  */
   public function catalogo_distrito_add(Request $request) {
    if(!$request->isXmlHttpRequest() AND  !$this->access() ) {
      return new JsonResponse([ 'data' => array('' => '' ) ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
    }
        try {
          $nombre = $request->get('nombre');
          $canton = $request->get('canton');
          $xid = $request->get('xid');
          $em = $this->getDoctrine()->getManager();
          if($xid == ""){
             $var = new Distrito();
          }else{
             $var = $em->getRepository(Distrito::class)->find($xid);
          }
          $var->setDistritodescripcion($nombre);
          $var->setCantonid($em->getReference('App\Entity\Canton', $canton));
          $em->persist($var);
          $em->flush();
      $message = ($xid === null) ? "Registro Guardado Exitosamente" : "Registro Actualizado Exitosamente";
      return new JsonResponse([ 'message' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
    } catch (Exception $e) {
    	 $message = "Ha ocurrido un error";
      return new JsonResponse([ 'data' => $message ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
    }
  }

  /**
    * @Route("Catalogos/DistritoDelete", name="catalogo_distrito_delete", methods={"POST"})
    */
  public function catalogo_distrito_delete(Request $request){
   if(!$request->isXmlHttpRequest() AND  !$this->access() ) {
    return new JsonResponse([ 'data' => array('' => '' ) ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
   }
   try {
       $ids = $request->get('ids');
       $em = $this->getDoctrine()->getManager();
       foreach ($ids as $id) {
           $rol = $this->getDoctrine()->getRepository(Distrito::class)->find($id['id']);
           $em->remove($rol);
           $em->flush();
    }
      $message = "Registros eliminados exitosamente";
      return new JsonResponse([ 'message' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
    } catch (Exception $e) {
       $message = "Ha ocurrido un error";
       return new JsonResponse([ 'data' => $message ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
    }
  }
  private function access(){
   $session = new Session();
   if ( $session->get('useridrol') >= $this->rolAccess )
     return TRUE;
   else
     return FALSE;
  }
}
