<?php

namespace App\Controller\Catalog;

use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use App\Entity\Centroeduc;
use App\Entity\Distrito;
use App\Entity\Distritopoblacion;
use App\Entity\Sectormep;
use App\Entity\Nivelmep;
use App\Entity\Direccionregional;
use App\Entity\Poblado;
use App\Entity\Provincia;

class CatalogosEducacionController extends AbstractController
{
    private const  usuariocreo = "Desarrollador Creador";
    private const  usuariomodifico = "Desarrollador Modificador";
    /**
     * @Route("CatalogosEducacion/CentroEducativo", name="centro_educativo_index")
     */
    public function centro_educativo()
    {
        $select['provincias'] = $this->getDoctrine()->getRepository(Provincia::class)->findAll();
        $select['regional'] =  $this->getDoctrine()->getRepository(Direccionregional::class)->findAll();
    	$select['distritos'] = $this->getDoctrine()->getRepository(Distrito::class)->findAll();
    	$select['poblados'] =  $this->getDoctrine()->getRepository(Poblado::class)->findAll();
    	$select['sectores'] =  $this->getDoctrine()->getRepository(Sectormep::class)->findAll();
    	$select['niveles'] =   $this->getDoctrine()->getRepository(Nivelmep::class)->findAll();
        return $this->render('ccp/catalog/catalogos_educacion/centro_educativo.html.twig',
        	array(
            	'controller_name' => 'CentroEducativoController', 'select' => $select
        	)
        );
    }


    /**
     * @Route("CatalogosEducacion/getAllCentrosEducativos/json", name="get_all_centro_educativo_json")
     */
    public function obtener_todos_centros_educativos()
    {
    	$em = $this->getDoctrine()->getManager();
    	$query = $em->createQuery(
        	'SELECT
        		c.centroeducid,
        		c.centroeducnombre,
        		r.direccionregionalnombre,
        		c.centroeduccircuito,
        		d.distritodescripcion,
        		p.pobladonombre,
        		s.sectormepdescripcion,
        		n.nivelmepdescripcion,
                r.direccionregionalid,
                p.pobladoid,
                pr.provinciaid,
                ca.cantonid,
                d.distritoid,
                s.sectormepid,
                n.nivelmepid

        	 FROM App\Entity\Centroeduc c
        	 JOIN App\Entity\Distrito d WITH c.distritoid = d.distritoid
        	 JOIN App\ENTITY\Sectormep s WITH c.sectormepid = s.sectormepid
        	 JOIN App\Entity\Nivelmep n WITH c.nivelmepid = n.nivelmepid
             JOIN App\Entity\Direccionregional r WITH c.direccionregionalid = r.direccionregionalid
             JOIN App\Entity\Poblado p WITH c.pobladoid = p.pobladoid
             JOIN App\Entity\Canton ca WITH d.cantonid = ca.cantonid
             JOIN App\Entity\Provincia pr WITH ca.provinciaid = pr.provinciaid
             '
    	);
    $centros_educativos = $query->getArrayResult();
    return new JsonResponse([ 'data' => $centros_educativos ], Response::HTTP_OK, ['content-type'=>'application/json']);
    }


     /**
     * @Route("CatalogosEducacion/AddCentrosEducativos/json", name="add_centro_educativo", methods={"POST"})
     */
      public function add_centro_educativo(Request $request)
    {

        try {
        $nombreeduc = $request->get('nombreeduc');
        $distrito = $request->get('distrito');
		$regional = $request->get('regional');
		$circuito = $request->get('circuito');
		$poblado = $request->get('poblado');
		$sector = $request->get('sector');
		$nivel = $request->get('nivel');
        $session = $request->getSession();
        $usuario = $session->get('username');

        $centroeducativoid = $request->get('centroeducativoid');

		$em = $this->getDoctrine()->getManager();

        if($centroeducativoid == ""){
            $centro_educativo = new Centroeduc();
            $centro_educativo->setUsuariocreo($usuario);
        }else{
            $centro_educativo = $em->getRepository(Centroeduc::class)->find($centroeducativoid);
            $centro_educativo->setUsuariomodifico($usuario);
        }

        $centro_educativo->setCentroeducnombre($nombreeduc);
        $centro_educativo->setCentroeduccircuito($circuito);
        $centro_educativo->setDireccionregionalid($em->getReference('App\Entity\Direccionregional', $regional));
        $centro_educativo->setPobladoid($em->getReference('App\Entity\Poblado', $poblado));
        $centro_educativo->setDistritoid($em->getReference('App\Entity\Distrito', $distrito));
        $centro_educativo->setNivelmepid($em->getReference('App\Entity\Nivelmep', $nivel));
        $centro_educativo->setSectormepid($em->getReference('App\Entity\Sectormep', $sector));

        $em->persist($centro_educativo);
        $em->flush();
        $message = ($centroeducativoid === "") ? "Registro Guardado Exitosamente" : "Registro Actualizado Exitosamente";
        return new JsonResponse([ 'message' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
        } catch (Exception $e) {
        	$message = "Ha ocurrido un error" + $e;
            return new JsonResponse([ 'data' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
        }

    }

     /**
     * @Route("CatalogosEducacion/DeleteCentrosEducativos/json", name="delete_centros_educativos", methods={"POST"})
     */
      public function delete_centros_educativos(Request $request)
    {
        try {
        $ids = $request->get('ids');
        $em = $this->getDoctrine()->getManager();
        foreach ($ids as $id) {
            $centro_educativo = $this->getDoctrine()->getRepository(Centroeduc::class)->find($id['id']);
            $em->remove($centro_educativo);
            $em->flush();
        }
        $message = "Registros eliminados exitosamente";
        return new JsonResponse([ 'message' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
        } catch (Exception $e) {
            $message = "Ha ocurrido un error" + $e;
            return new JsonResponse([ 'data' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
        }

    }

    /**
     * @Route("CatalogosEducacion/ObtenerDistritosCanton/json", name="obtener_distrito_canton", methods={"POST"})
     */
      public function obtener_distrito_canton(Request $request)
    {
        try {
        $id = $request->get('id');
        $em = $this->getDoctrine()->getManager();
        $query = $em->createQuery(
            'SELECT d.distritoid,
                    d.distritodescripcion
             FROM App\Entity\Distrito d
             WHERE d.cantonid = :id'
        );
        $query->setParameter('id', $id);
        $data = $query->getArrayResult();
        return new JsonResponse([ 'data' => $data ], Response::HTTP_OK, ['content-type'=>'application/json']);
        } catch (Exception $e) {
            $message = "Ha ocurrido un error" + $e;
            return new JsonResponse([ 'data' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
        }

    }

    /**
     * @Route("CatalogosEducacion/ObtenerCantonesProvincia/json", name="obtener_canton_provincia", methods={"POST"})
     */
      public function obtener_canton_provincia(Request $request)
    {
        try {
        $id = $request->get('id');
        $em = $this->getDoctrine()->getManager();
        $query = $em->createQuery(
            'SELECT c.cantonid,
                    c.cantondescripcion
             FROM App\Entity\Canton c
             WHERE c.provinciaid = :id'
        );
        $query->setParameter('id', $id);
        $data = $query->getArrayResult();
        return new JsonResponse([ 'data' => $data ], Response::HTTP_OK, ['content-type'=>'application/json']);
        } catch (Exception $e) {
            $message = "Ha ocurrido un error" + $e;
            return new JsonResponse([ 'data' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
        }

    }

    /**
     * @Route("CatalogosEducacion/ObtenerAreasInteres/json", name="obtener_areas_interes", methods={"POST"})
     */
      public function obtener_areas_interes(Request $request)
    {
        try {
        $id = $request->get('id');
        $em = $this->getDoctrine()->getManager();

        $query = $em->createQuery(
            'SELECT a.areainteresid,
                    a.areainteresdescripcion
             FROM App\Entity\Areainteres a
             WHERE a.tipointeresid = :id'
        );
        $query->setParameter('id', $id);
        $data = $query->getArrayResult();
        return new JsonResponse([ 'data' => $data ], Response::HTTP_OK, ['content-type'=>'application/json']);
        } catch (Exception $e) {
            $message = "Ha ocurrido un error" + $e;
            return new JsonResponse([ 'data' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
        }

    }


    /**
     * @Route("CatalogosEducacion/ObtenerCursosInstitucion/json", name="obtener_cursos_institucion", methods={"POST"})
     */
      public function obtener_cursos_institucion(Request $request)
    {
        try {
        $id = $request->get('id');
        $session = $request->getSession();
        $centrocivicoid = $session->get('useridccp');
        $em = $this->getDoctrine()->getManager();
        $query = $em->createQuery(
            'SELECT c.cursoid,
                    c.cursonombre,
                    c.cursocodigo,
                    o.ofertafechaini,
                    o.ofertafechafin
             FROM App\Entity\Curso c
             LEFT JOIN App\Entity\Oferta o WITH o.cursoid = c.cursoid
             WHERE c.institucionid = :id AND c.centrocivicoid = :centrocivicoid'
        );
        $query->setParameter('id', $id);
        $query->setParameter('centrocivicoid', $centrocivicoid);
        $data = $query->getArrayResult();
        return new JsonResponse([ 'data' => $data ], Response::HTTP_OK, ['content-type'=>'application/json']);
        } catch (Exception $e) {
            $message = "Ha ocurrido un error" + $e;
            return new JsonResponse([ 'data' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
        }

    }

    /**
     * @Route("CatalogosEducacion/ObtenerNivelEducacion/json", name="obtener_nivel_educacion", methods={"POST"})
     */
      public function obtener_nivel_educacion(Request $request)
    {
        try {
        $id = $request->get('id');
        $em = $this->getDoctrine()->getManager();

        $sql  = "SELECT NivelEducativoID AS niveleducativoid,
                        NivelEducativoDescripcion AS niveleducativodescripcion
                 FROM NivelEducativo
                 WHERE NivelEducativo_ID = $id";

        $statement = $em->getConnection()->prepare($sql);
        $statement->execute();
        $result = $statement->fetchAll();
        return new JsonResponse([ 'data' => $result ], Response::HTTP_OK, ['content-type'=>'application/json']);
        } catch (Exception $e) {
            $message = "Ha ocurrido un error" + $e;
            return new JsonResponse([ 'data' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
        }

    }

    /**
     * @Route("CatalogosEducacion/ObtenerDiscpacidadSubcategoria/json", name="obtener_subcategoria_discapacidad", methods={"POST"})
     */
      public function obtener_subcategoria_discapacidad(Request $request)
    {
        try {
        $id = $request->get('id');
        $em = $this->getDoctrine()->getManager();

        $sql  = "SELECT DiscapacidadID AS discapacidadid,
                        DiscapacidadDescripcion AS discapacidaddescripcion
                 FROM Discapacidad
                 WHERE Discapacidad_ID = $id";

        $statement = $em->getConnection()->prepare($sql);
        $statement->execute();
        $result = $statement->fetchAll();
        return new JsonResponse([ 'data' => $result ], Response::HTTP_OK, ['content-type'=>'application/json']);
        } catch (Exception $e) {
            $message = "Ha ocurrido un error" + $e;
            return new JsonResponse([ 'data' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
        }

    }





}
