<?php

namespace App\Controller\Catalog;

use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use App\Entity\Curso;
use App\Entity\Oferta;
use Symfony\Component\HttpFoundation\Session\Session;

class CatalogosOfertaProgramaticaController extends AbstractController{
  private $rolAccess = 50;
  /**
   * @Route("Catalogos/OfertaProgramatica", name="catalogo_oferta_index")
   */
  public function catalogo_oferta_index()    {
   if ( $this->access() ){
    $select['curso'] = $this->getDoctrine()->getRepository(Curso::class)->findBy(array(), array('cursocodigo' => 'ASC'));
    return $this->render('ccp/catalog/oferta.html.twig', array( 'select' => $select ) );
   }
   else
     return $this->redirectToRoute('ccp_app_index', ['e'   => ""] );
  }

  /**
    * @Route("Catalogos/getAllOfertas/json", name="get_all_ofertas_json")
    */
  public function get_all_ofertas_json(Request $request) {
   if($request->isXmlHttpRequest() AND  $this->access() ) {
     $em  = $this->getDoctrine()->getManager();
     $sql = "SELECT c.CursoCodigo, c.CursoID, c.CursoNombre, o.OfertaDescripcion, o.OfertaFechaFin, o.OfertaFechaIni, o.OfertaID FROM Oferta o INNER JOIN Curso c ON c.CursoID = o.CursoID";
     $stm = $em->getConnection()->prepare( $sql );
     $stm->execute();
     return new JsonResponse([ 'data' => $stm->fetchAll() ], Response::HTTP_OK, ['content-type'=>'application/json']);
   } else {
     return new JsonResponse([ 'data' => array('' => '' ) ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
   }
  }

  /**
  * @Route("Catalogos/OfertaAdd", name="catalogo_oferta_add", methods={"POST"})
  */
   public function catalogo_cursos_add(Request $request) {
    if(!$request->isXmlHttpRequest() AND  !$this->access() ) {
      return new JsonResponse([ 'data' => array('' => '' ) ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
    }
    try {
      $nombre = $request->get('nombre');
      $curso  = $request->get('curso');
      $inicio = $request->get('ini');
      $fin    = $request->get('fin');
      $xid = $request->get('xid');
      $em = $this->getDoctrine()->getManager();
      if($xid == ""){
         $var = new Oferta();
      }else{
         $var = $em->getRepository(Oferta::class)->find($xid);
      }
      $var->setOfertadescripcion($nombre);
      $var->setCursoid($em->getReference('App\Entity\Curso', $curso));
      $var->setOfertafechaini( $inicio );
      $var->setOfertafechafin( $fin );
      $em->persist($var);
      $em->flush();
      $message = ($xid === null) ? "Registro Guardado Exitosamente" : "Registro Actualizado Exitosamente";
      return new JsonResponse([ 'message' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
    } catch (Exception $e) {
    	$message = "Ha ocurrido un error";
      return new JsonResponse([ 'data' => $message ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
    }
  }

  /**
    * @Route("Catalogos/OfertaDelete", name="catalogo_oferta_delete", methods={"POST"})
    */
  public function catalogo_cursos_delete(Request $request){
   if(!$request->isXmlHttpRequest() AND  !$this->access() ) {
    return new JsonResponse([ 'data' => array('' => '' ) ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
   }
   try {
       $ids = $request->get('ids');
       $em = $this->getDoctrine()->getManager();
       foreach ($ids as $id) {
           $rol = $this->getDoctrine()->getRepository(Oferta::class)->find($id['id']);
           $em->remove($rol);
           $em->flush();
      }
      $message = "Registros eliminados exitosamente";
      return new JsonResponse([ 'message' => $message ], Response::HTTP_OK, ['content-type'=>'application/json']);
    } catch (Exception $e) {
       $message = "Ha ocurrido un error";
       return new JsonResponse([ 'data' => $message ], Response::HTTP_NOT_FOUND, ['content-type'=>'application/json']);
    }
  }

  private function access(){
   $session = new Session();
   if ( $session->get('useridrol') >= $this->rolAccess )
     return TRUE;
   else
     return FALSE;
  }
}
