<?php

namespace App\Entity;

use Doctrine\ORM\Mapping as ORM;

/**
 * Centroeduc
 *
 * @ORM\Table(name="CentroEduc", indexes={@ORM\Index(name="ICENTROEDUC1", columns={"DistritoID"}), @ORM\Index(name="ICENTROEDUC2", columns={"NivelMEPId"}), @ORM\Index(name="ICENTROEDUC3", columns={"SectorMEPId"})})
 * @ORM\Entity
 */
class Centroeduc
{
    /**
     * @var int
     *
     * @ORM\Column(name="CentroEducId", type="integer", nullable=false, options={"comment"="Genera un número consecutivo para cada uno de los Centros Educativos y se utiliza como llave principal."})
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $centroeducid;

    /**
     * @var string
     *
     * @ORM\Column(name="CentroEducNombre", type="string", length=150, nullable=false, options={"comment"="Contiene el Nombre de cada uno de los Centros Educativos del País."})
     */
    private $centroeducnombre;

    /**
     * @var string
     *
     * @ORM\Column(name="usuarioCreo", type="string", length=50, nullable=false, options={"comment"="Contiene el Nombre del usuario que ha creado el registro"})
     */
    private $usuariocreo;

    /**
     * @var string
     *
     * @ORM\Column(name="usuarioModifico", type="string", length=50, nullable=false, options={"comment"="Contiene el Nombre del usuario que ha modificado el registro"})
     */
    private $usuariomodifico;

    /**
     * @var string
     *
     * @ORM\Column(name="CentroEducCircuito", type="string", length=3, nullable=false, options={"comment"="Registrar el Circuito del Centro Educativo."})
     */
    private $centroeduccircuito;

    /**
     * @var \Distrito
     *
     * @ORM\ManyToOne(targetEntity="Distrito")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="DistritoID", referencedColumnName="DistritoID")
     * })
     */
    private $distritoid;

    /**
     * @var \Nivelmep
     *
     * @ORM\ManyToOne(targetEntity="Nivelmep")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="NivelMEPId", referencedColumnName="NivelMEPId")
     * })
     */
    private $nivelmepid;

    /**
     * @var \Sectormep
     *
     * @ORM\ManyToOne(targetEntity="Sectormep")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="SectorMEPId", referencedColumnName="SectorMEPId")
     * })
     */
    private $sectormepid;

    /**
     * @var \DireccionRegional
     *
     * @ORM\ManyToOne(targetEntity="Direccionregional")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="CentroEducDirecRegId", referencedColumnName="DireccionRegionalID")
     * })
     */
    private $direccionregionalid;

    /**
     * @var \Poblado
     *
     * @ORM\ManyToOne(targetEntity="Poblado")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="PobladoId", referencedColumnName="PobladoID")
     * })
     */
    private $pobladoid;


    public function getCentroeducid(): ?int
    {
        return $this->centroeducid;
    }

    public function getCentroeducnombre(): ?string
    {
        return $this->centroeducnombre;
    }

    public function setCentroeducnombre(string $centroeducnombre): self
    {
        $this->centroeducnombre = $centroeducnombre;

        return $this;
    }

    public function getCentroeducdirecreg(): ?string
    {
        return $this->centroeducdirecreg;
    }

    public function setCentroeducdirecreg(string $centroeducdirecreg): self
    {
        $this->centroeducdirecreg = $centroeducdirecreg;

        return $this;
    }

    public function getCentroeduccircuito(): ?string
    {
        return $this->centroeduccircuito;
    }

    public function setCentroeduccircuito(string $centroeduccircuito): self
    {
        $this->centroeduccircuito = $centroeduccircuito;

        return $this;
    }

    public function getDistritoid(): ?Distrito
    {
        return $this->distritoid;
    }

    public function setDistritoid(?Distrito $distritoid): self
    {
        $this->distritoid = $distritoid;

        return $this;
    }

    public function getNivelmepid(): ?Nivelmep
    {
        return $this->nivelmepid;
    }

    public function setNivelmepid(?Nivelmep $nivelmepid): self
    {
        $this->nivelmepid = $nivelmepid;

        return $this;
    }

    public function getSectormepid(): ?Sectormep
    {
        return $this->sectormepid;
    }

    public function setSectormepid(?Sectormep $sectormepid): self
    {
        $this->sectormepid = $sectormepid;

        return $this;
    }

    public function getDireccionregionalid(): ?DireccionRegional
    {
        return $this->direccionregionalid;
    }

    public function setDireccionregionalid(?DireccionRegional $direccionregionalid): self
    {
        $this->direccionregionalid = $direccionregionalid;

        return $this;
    }

    public function getPobladoid(): ?Poblado
    {
        return $this->pobladoid;
    }

    public function setPobladoid(?Poblado $pobladoid): self
    {
        $this->pobladoid = $pobladoid;

        return $this;
    }


    public function getUsuariocreo(): ?string
    {
        return $this->usuariocreo;
    }

    public function setUsuariocreo(string $usuariocreo): self
    {
        $this->usuariocreo = $usuariocreo;

        return $this;
    }

    public function getUsuariomodifico(): ?string
    {
        return $this->usuariomodifico;
    }

    public function setUsuariomodifico(string $usuariomodifico): self
    {
        $this->usuariomodifico = $usuariomodifico;

        return $this;
    }


}
